/**
 * Dummy chat thread interface for testing.
 * @internal
 */
export class DummyGenAIChatThread {
    async loadHistory(_fromInteractionId, { signal }) {
        await cancellableTimeout(100, signal);
        return Promise.resolve({
            interactions: [],
            threadId: "",
        });
    }
    async reset() {
        await cancellableTimeout(100);
    }
    async saveUserFeedback(_interactionId, _feedback) { }
    query(_userMessage) {
        return new DummyGenAIChatQueryBuilder();
    }
}
/**
 * Dummy query builder for GenAI chat
 * @internal
 */
export class DummyGenAIChatQueryBuilder {
    withSearchLimit() {
        return this;
    }
    withCreateLimit() {
        return this;
    }
    withUserContext() {
        return this;
    }
    async query({ signal }) {
        await cancellableTimeout(100, signal);
        return Promise.resolve({
            routing: {
                useCase: "GENERAL",
                reasoning: "",
            },
            textResponse: "",
            foundObjects: {
                objects: [],
                reasoning: "",
            },
            createdVisualizations: {
                objects: [],
                reasoning: "",
            },
        });
    }
    stream() {
        return new ReadableStream({
            start: async (controller) => {
                await cancellableTimeout(100);
                controller.enqueue({
                    routing: {
                        useCase: "GENERAL",
                        reasoning: "",
                    },
                    textResponse: "",
                    foundObjects: {
                        objects: [],
                        reasoning: "",
                    },
                    createdVisualizations: {
                        objects: [],
                        reasoning: "",
                    },
                });
            },
        });
    }
}
const cancellableTimeout = async (ms, signal) => {
    return new Promise((res, rej) => {
        if (signal?.aborted) {
            rej(signal.reason);
        }
        const tm = setTimeout(res, ms);
        signal?.addEventListener("abort", () => {
            clearTimeout(tm);
            rej(signal.reason);
        });
    });
};
//# sourceMappingURL=DummyGenAIChatThread.js.map